@@ -34,6 +34,8 @@ SOF3
 SWFN
 SWOF
 TABDIMS
+VFPPROD
+VFPINJ
 WCONHIST
 WCONINJE
 WCONINJH
