@@ -25,7 +25,7 @@ try:
 except ImportError:
     pass
 
-from ecl2df import common, inferdims
+from ecl2df import common, getLogger_ecl2csv, inferdims
 
 from .common import write_dframe_stdout_file
 from .eclfiles import EclFiles
@@ -118,6 +118,11 @@ def df(
         dframe["KEYWORD"] = pd.Categorical(dframe["KEYWORD"], SUPPORTED_KEYWORDS)
         dframe.sort_values(["SATNUM", "KEYWORD"], inplace=True)
         dframe["KEYWORD"] = dframe["KEYWORD"].astype(str)
+        logger.info(
+            "Extracted keywords %s for %i SATNUMs",
+            dframe["KEYWORD"].unique(),
+            len(dframe["SATNUM"].unique()),
+        )
         return dframe
     return pd.DataFrame()
 
@@ -184,8 +189,9 @@ def fill_reverse_parser(parser: argparse.ArgumentParser) -> argparse.ArgumentPar
 
 def satfunc_main(args) -> None:
     """Entry-point for module, for command line utility"""
-    if args.verbose:
-        logging.basicConfig(level=logging.INFO)
+    logger = getLogger_ecl2csv(  # pylint: disable=redefined-outer-name
+        __name__, vars(args)
+    )
     eclfiles = EclFiles(args.DATAFILE)
     if eclfiles:
         deck = eclfiles.get_ecldeck()
@@ -196,7 +202,9 @@ def satfunc_main(args) -> None:
     else:
         # This might be an include file for which we have to infer/guess
         # TABDIMS. Then we send it to df() as a string
-        satfunc_df = df(Path(args.DATAFILE).read_text(), keywords=args.keywords)
+        satfunc_df = df(
+            Path(args.DATAFILE).read_text(encoding="utf-8"), keywords=args.keywords
+        )
     if "SATNUM" in satfunc_df and "KEYWORD" in satfunc_df:
         satnums = str(len(satfunc_df["SATNUM"].unique()))
         keywords = str(satfunc_df["KEYWORD"].unique())
@@ -214,8 +222,9 @@ def satfunc_main(args) -> None:
 
 def satfunc_reverse_main(args) -> None:
     """For command line utility for CSV to Eclipse"""
-    if args.verbose:
-        logging.basicConfig(level=logging.INFO)
+    logger = getLogger_ecl2csv(  # pylint: disable=redefined-outer-name
+        __name__, vars(args)
+    )
     satfunc_df = pd.read_csv(args.csvfile)
     logger.info("Parsed %s", args.csvfile)
     inc_string = df2ecl(satfunc_df, keywords=args.keywords)
@@ -343,7 +352,7 @@ def _df2ecl_satfuncs(
 ) -> str:
     if dframe.empty:
         return "-- No data!\n"
-    string = "{}\n".format(keyword)
+    string = f"{keyword}\n"
     string += common.comment_formatter(comment)
 
     if "KEYWORD" not in dframe:
@@ -369,6 +378,6 @@ def _df2ecl_satfuncs(
 
     # Loop over every SATNUM
     for satnum in subset.index.unique():
-        string += "-- SATNUM: {}\n".format(satnum)
+        string += f"-- SATNUM: {satnum}\n"
         string += _df2ecl_satfuncs_satnum(keyword, subset[subset.index == satnum])
     return string + "\n"
